ParameterValue

Enum ParameterValue 

pub enum ParameterValue {
    String(String),
    Integer(i64),
    Float(f64),
    Boolean(bool),
    Array(Vec<ParameterValue>),
    Object(HashMap<String, ParameterValue>),
    Null,
}
A parameter value that can be nested and supports various data types.

Variants



String(String)



Integer(i64)



Float(f64)



Boolean(bool)



Array(Vec<ParameterValue>)



Object(HashMap<String, ParameterValue>)



Null

Implementations

Source

impl ParameterValue

pub fn object_from<I>(items: I) -> Self
where I: IntoIterator<Item = (String, ParameterValue)>,

Create an object from a collection of key-value pairs where values can be of different types.

pub fn object_builder() -> ObjectBuilder

Create an object using a builder pattern for mixed types

pub fn array_builder() -> ArrayBuilder

Create an array using a builder pattern for mixed types

pub fn build_object<F>(f: F) -> Self
where F: FnOnce(&mut ObjectBuilder) -> &mut ObjectBuilder,

Create an object by calling a closure with a builder

pub fn build_array<F>(f: F) -> Self
where F: FnOnce(&mut ArrayBuilder) -> &mut ArrayBuilder,

Create an array by calling a closure with a builder

Source

impl ParameterValue

pub fn array(items: Vec<impl Into<ParameterValue>>) -> Self

Create a new array parameter value.

pub fn object(map: impl Into<HashMap<String, ParameterValue>>) -> Self

Create a new object parameter value.