pub fn set_default_response_builder(builder: impl ResponseBuilder + 'static)Expand description
Set the global default response builder for all ServiceError instances. This should be called once at application startup.
pub fn set_default_response_builder(builder: impl ResponseBuilder + 'static)Set the global default response builder for all ServiceError instances. This should be called once at application startup.