ServiceError

Struct ServiceError 

pub struct ServiceError<'a> {
    pub code: u32,
    pub name: Cow<'a, str>,
    pub http_status: u16,
    pub message: Cow<'a, str>,
    pub arguments: Vec<String>,
    pub parameters: Option<HashMap<String, ParameterValue>>,
    /* private fields */
}
A ServiceError represents a specific error within the software.

Fields

code: u32

An internal error code that represents a specific error within the system.

name: Cow<'a, str>

A capitalized error name that represents the error type.

http_status: u16

The respective HTTP status code that should be returned to the client.

message: Cow<'a, str>

A human-readable error message that describes the error in more detail.

arguments: Vec<String>

Arguments for message formatting

parameters: Option<HashMap<String, ParameterValue>>

Optional parameters as key-value pairs

Implementations

Source

impl<'a> ServiceError<'a>

pub const fn new( code: u32, name: &'a str, status: u16, message: &'a str, ) -> Self

Create a new ServiceError instance.

pub fn bind(self, value: impl ToString) -> Self

Add an argument for message formatting.

pub fn parameter( self, key: impl ToString, value: impl Into<ParameterValue>, ) -> Self

Add an optional parameter.

pub fn parameters<K, V, I>(self, params: I) -> Self
where K: Into<String>, V: Into<ParameterValue>, I: IntoIterator<Item = (K, V)>,

Add multiple parameters at once.

pub fn with_response_builder( self, builder: impl ResponseBuilder + 'static, ) -> Self

Set a custom response builder for formatting the response.