Crate axum_service_errors
Source - param_array
- Macro to create ParameterValue arrays with mixed types easily
- param_object
- Macro to create ParameterValue objects with mixed types easily
- ArrayBuilder
- Builder for creating ParameterValue arrays with mixed types
- ObjectBuilder
- Builder for creating ParameterValue objects with mixed types
- PlainTextResponseBuilder
- A simple plain text response builder.
- ServiceError
- A
ServiceError represents a specific error within the software.
- ParameterValue
- A parameter value that can be nested and supports various data types.
- ResponseBuilder
- A trait for building custom response formats from ServiceError data.
- set_default_response_builder
- Set the global default response builder for all ServiceError instances.
This should be called once at application startup.